aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Sidrane <david_s5@nscdg.com>2015-04-06 11:46:19 -1000
committerDavid Sidrane <david_s5@nscdg.com>2015-04-07 07:49:55 -1000
commite28147bc960d771c3d09a5ec967ceb5242c3f02c (patch)
tree02a9ac80c6a1640ea0b20915378f77efa8d2c3d8
parent6dcdb1a2bcefad175b2e729f9bd86ec727ed3a36 (diff)
downloadpx4-firmware-e28147bc960d771c3d09a5ec967ceb5242c3f02c.tar.gz
px4-firmware-e28147bc960d771c3d09a5ec967ceb5242c3f02c.tar.bz2
px4-firmware-e28147bc960d771c3d09a5ec967ceb5242c3f02c.zip
Changed to Support boardctrl in upstream NuttX
-rw-r--r--nuttx-configs/mavstation/nsh/defconfig2
-rw-r--r--src/drivers/boards/aerocore/aerocore_init.c6
-rw-r--r--src/drivers/boards/aerocore/board_config.h19
-rw-r--r--src/drivers/boards/mavstation/mavstation_init.c3
-rw-r--r--src/drivers/boards/px4fmu-v1/board_config.h20
-rw-r--r--src/drivers/boards/px4fmu-v1/px4fmu_init.c6
-rw-r--r--src/drivers/boards/px4fmu-v2/board_config.h19
-rw-r--r--src/drivers/boards/px4fmu-v2/px4fmu2_init.c6
-rw-r--r--src/drivers/boards/px4io-v1/px4io_init.c2
-rw-r--r--src/drivers/boards/px4io-v2/px4iov2_init.c2
10 files changed, 14 insertions, 71 deletions
diff --git a/nuttx-configs/mavstation/nsh/defconfig b/nuttx-configs/mavstation/nsh/defconfig
index 6f752df2d..bcb0e3d22 100644
--- a/nuttx-configs/mavstation/nsh/defconfig
+++ b/nuttx-configs/mavstation/nsh/defconfig
@@ -618,7 +618,7 @@ CONFIG_NSH_LIBRARY=y
# CONFIG_NSH_CONSOLE - Use serial console front end
# CONFIG_NSH_TELNET - Use telnetd console front end
# CONFIG_NSH_ARCHINIT - Platform provides architecture
-# specific initialization (nsh_archinitialize()).
+# specific initialization (board_app_initialize()).
#
# If CONFIG_NSH_TELNET is selected:
# CONFIG_NSH_IOBUFFER_SIZE -- Telnetd I/O buffer size
diff --git a/src/drivers/boards/aerocore/board_config.h b/src/drivers/boards/aerocore/board_config.h
index 19518d73d..85de14c28 100644
--- a/src/drivers/boards/aerocore/board_config.h
+++ b/src/drivers/boards/aerocore/board_config.h
@@ -171,25 +171,6 @@ __BEGIN_DECLS
extern void stm32_spiinitialize(void);
-/****************************************************************************
- * Name: nsh_archinitialize
- *
- * Description:
- * Perform architecture specific initialization for NSH.
- *
- * CONFIG_NSH_ARCHINIT=y :
- * Called from the NSH library
- *
- * CONFIG_BOARD_INITIALIZE=y, CONFIG_NSH_LIBRARY=y, &&
- * CONFIG_NSH_ARCHINIT=n :
- * Called from board_initialize().
- *
- ****************************************************************************/
-
-#ifdef CONFIG_NSH_LIBRARY
-int nsh_archinitialize(void);
-#endif
-
#endif /* __ASSEMBLY__ */
__END_DECLS
diff --git a/src/drivers/boards/mavstation/mavstation_init.c b/src/drivers/boards/mavstation/mavstation_init.c
index a4ded45a8..8a1b8f506 100644
--- a/src/drivers/boards/mavstation/mavstation_init.c
+++ b/src/drivers/boards/mavstation/mavstation_init.c
@@ -34,8 +34,7 @@
/**
* @file mavstation_init.c
*
- * mavstation-specific early startup code. This file implements the
- * nsh_archinitialize() function that is called early by nsh during startup.
+ * mavstation-specific early startup code.
*
* Code here is run before the rcS script is invoked; it should start required
* subsystems and perform board-specific initialisation.
diff --git a/src/drivers/boards/px4fmu-v1/board_config.h b/src/drivers/boards/px4fmu-v1/board_config.h
index 17fa9c542..38738cb48 100644
--- a/src/drivers/boards/px4fmu-v1/board_config.h
+++ b/src/drivers/boards/px4fmu-v1/board_config.h
@@ -46,6 +46,7 @@
#include <nuttx/config.h>
#include <nuttx/compiler.h>
#include <stdint.h>
+#include <nuttx/board.h>
__BEGIN_DECLS
@@ -210,25 +211,6 @@ extern void stm32_spiinitialize(void);
extern void stm32_usbinitialize(void);
-/****************************************************************************
- * Name: nsh_archinitialize
- *
- * Description:
- * Perform architecture specific initialization for NSH.
- *
- * CONFIG_NSH_ARCHINIT=y :
- * Called from the NSH library
- *
- * CONFIG_BOARD_INITIALIZE=y, CONFIG_NSH_LIBRARY=y, &&
- * CONFIG_NSH_ARCHINIT=n :
- * Called from board_initialize().
- *
- ****************************************************************************/
-
-#ifdef CONFIG_NSH_LIBRARY
-int nsh_archinitialize(void);
-#endif
-
#endif /* __ASSEMBLY__ */
__END_DECLS
diff --git a/src/drivers/boards/px4fmu-v2/board_config.h b/src/drivers/boards/px4fmu-v2/board_config.h
index 6188e29ae..541f5c50a 100644
--- a/src/drivers/boards/px4fmu-v2/board_config.h
+++ b/src/drivers/boards/px4fmu-v2/board_config.h
@@ -238,25 +238,6 @@ extern void stm32_spiinitialize(void);
extern void stm32_usbinitialize(void);
-/****************************************************************************
- * Name: nsh_archinitialize
- *
- * Description:
- * Perform architecture specific initialization for NSH.
- *
- * CONFIG_NSH_ARCHINIT=y :
- * Called from the NSH library
- *
- * CONFIG_BOARD_INITIALIZE=y, CONFIG_NSH_LIBRARY=y, &&
- * CONFIG_NSH_ARCHINIT=n :
- * Called from board_initialize().
- *
- ****************************************************************************/
-
-#ifdef CONFIG_NSH_LIBRARY
-int nsh_archinitialize(void);
-#endif
-
#endif /* __ASSEMBLY__ */
__END_DECLS
diff --git a/src/drivers/boards/px4io-v1/px4io_init.c b/src/drivers/boards/px4io-v1/px4io_init.c
index 41423ddb4..c36cca9f9 100644
--- a/src/drivers/boards/px4io-v1/px4io_init.c
+++ b/src/drivers/boards/px4io-v1/px4io_init.c
@@ -35,7 +35,7 @@
* @file px4io_init.c
*
* PX4IO-specific early startup code. This file implements the
- * nsh_archinitialize() function that is called early by nsh during startup.
+ * board_app_initialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required
* subsystems and perform board-specific initialisation.
diff --git a/src/drivers/boards/px4io-v2/px4iov2_init.c b/src/drivers/boards/px4io-v2/px4iov2_init.c
index f6440c833..8d2d5a92c 100644
--- a/src/drivers/boards/px4io-v2/px4iov2_init.c
+++ b/src/drivers/boards/px4io-v2/px4iov2_init.c
@@ -35,7 +35,7 @@
* @file px4iov2_init.c
*
* PX4FMU-specific early startup code. This file implements the
- * nsh_archinitialize() function that is called early by nsh during startup.
+ * board_app_initialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required
* subsystems and perform board-specific initialisation.
diff --git a/src/drivers/boards/aerocore/aerocore_init.c b/src/drivers/boards/aerocore/aerocore_init.c
index 1a6eead3f..8376bad75 100644
--- a/src/drivers/boards/aerocore/aerocore_init.c
+++ b/src/drivers/boards/aerocore/aerocore_init.c
@@ -35,7 +35,7 @@
* @file aerocore_init.c
*
* AeroCore-specific early startup code. This file implements the
* nsh_archinitialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required
* subsystems and perform board-specific initialisation.
@@ -202,7 +202,7 @@ stm32_boardinitialize(void)
}
/****************************************************************************
- * Name: nsh_archinitialize
+ * Name: board_app_initialize
*
* Description:
* Perform architecture specific initialization
@@ -226,7 +226,7 @@ __EXPORT int matherr(struct exception *e)
}
#endif
-__EXPORT int nsh_archinitialize(void)
+__EXPORT int board_app_initialize(void)
{
/* configure ADC pins */
@@ -35,7 +35,7 @@
*
* AeroCore-specific early startup code. This file implements the
- * nsh_archinitialize() function that is called early by nsh during startup.
+ * board_app_initialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required
diff --git a/src/drivers/boards/px4fmu-v1/px4fmu_init.c b/src/drivers/boards/px4fmu-v1/px4fmu_init.c
index c6207312f..7dd542366 100644
--- a/src/drivers/boards/px4fmu-v1/px4fmu_init.c
+++ b/src/drivers/boards/px4fmu-v1/px4fmu_init.c
@@ -35,7 +35,7 @@
* @file px4fmu_init.c
*
* PX4FMU-specific early startup code. This file implements the
* nsh_archinitialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required
* subsystems and perform board-specific initialisation.
@@ -116,7 +116,7 @@ __EXPORT void stm32_boardinitialize(void)
}
/****************************************************************************
- * Name: nsh_archinitialize
+ * Name: board_app_initialize
*
* Description:
* Perform architecture specific initialization
@@ -141,7 +141,7 @@ __EXPORT int matherr(struct exception *e)
}
#endif
-__EXPORT int nsh_archinitialize(void)
+__EXPORT int board_app_initialize(void)
{
int result;
@@ -35,7 +35,7 @@
*
* PX4FMU-specific early startup code. This file implements the
- * nsh_archinitialize() function that is called early by nsh during startup.
+ * board_app_initialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required
diff --git a/src/drivers/boards/px4fmu-v2/px4fmu2_init.c b/src/drivers/boards/px4fmu-v2/px4fmu2_init.c
index 74bbfa4c6..9bb2cc166 100644
--- a/src/drivers/boards/px4fmu-v2/px4fmu2_init.c
+++ b/src/drivers/boards/px4fmu-v2/px4fmu2_init.c
@@ -35,7 +35,7 @@
* @file px4fmu2_init.c
*
* PX4FMUv2-specific early startup code. This file implements the
* nsh_archinitialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required
* subsystems and perform board-specific initialization.
@@ -186,7 +186,7 @@ stm32_boardinitialize(void)
}
/****************************************************************************
- * Name: nsh_archinitialize
+ * Name: board_app_initialize
*
* Description:
* Perform architecture specific initialization
@@ -212,7 +212,7 @@ __EXPORT int matherr(struct exception *e)
}
#endif
-__EXPORT int nsh_archinitialize(void)
+__EXPORT int board_app_initialize(void)
{
/* configure ADC pins */
@@ -35,7 +35,7 @@
*
* PX4FMUv2-specific early startup code. This file implements the
- * nsh_archinitialize() function that is called early by nsh during startup.
+ * board_app_initialize() function that is called early by nsh during startup.
*
* Code here is run before the rcS script is invoked; it should start required